import { NestFactory } from '@nestjs/core';
import { SwaggerModule, DocumentBuilder } from '@nestjs/swagger';
import { AppModule } from './app.module';
import { WinstonModule } from 'nest-winston';

import { createLogger } from './logger';
import { ValidationPipe } from '@nestjs/common';

const DEFAULT_APP_PORT = 3000;

async function bootstrap() {
  const instance = createLogger({});

  const app = await NestFactory.create(AppModule, {
    logger: WinstonModule.createLogger({ instance }),
  });

  // Use the shutdown hooks
  // app.enableShutdownHooks();

  // Use Validation Pipe
  app.useGlobalPipes(new ValidationPipe());

  // Setup the Swagger if ENABLE_SWAGGER is True OR NODE_ENV is NOT 'production'
  if (
    process.env.NODE_ENV !== 'production' ||
    process.env.ENABLE_SWAGGER === 'true'
  ) {
    const swaggerDoc = SwaggerModule.createDocument(
      app,
      new DocumentBuilder()
        .setTitle('Basic Nestjs API Service')
        .setDescription('Boilerplate project of the Basic Nestjs API Service')
        .setVersion('1.0')
        .addServer(process.env.SWAGGER_SERVER_PATH)
        .build(),
    );
    SwaggerModule.setup('api', app, swaggerDoc);
  }

  // Start the web app
  await app.listen(process.env.APP_PORT || DEFAULT_APP_PORT);
}
bootstrap();
