import { Injectable, Logger } from '@nestjs/common';
import { CreateUserDto } from './dto/create-user.dto';
import { UpdateUserDto } from './dto/update-user.dto';
import { User } from './entities/user.entity';
import { UserRepository } from './users.repository';

@Injectable()
export class UsersService {
  constructor(
    private readonly logger: Logger,
    private readonly userRepository: UserRepository,
  ) {}

  async create(createUserDto: CreateUserDto): Promise<User> {
    const user = User.createFromCreateUserDto(createUserDto, -1);
    await this.userRepository.add(user);
    return user;
  }

  async findAll(): Promise<User[]> {
    return this.userRepository.findAll();
  }

  async findOne(id: number): Promise<User> {
    return this.userRepository.get(id);
  }

  async update(id: number, updateUserDto: UpdateUserDto): Promise<User> {
    const user = User.createFromCreateUserDto(updateUserDto, id);
    return this.userRepository.update(id, user);
  }

  async remove(id: number): Promise<User> {
    return this.userRepository.delete(id);
  }
}
